/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calICalendarViewController.idl
 */

#ifndef __gen_calICalendarViewController_h__
#define __gen_calICalendarViewController_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class calICalendar; /* forward declaration */

class calIDateTime; /* forward declaration */

class calIEvent; /* forward declaration */

class calIItemBase; /* forward declaration */


/* starting interface:    calICalendarViewController */
#define CALICALENDARVIEWCONTROLLER_IID_STR "40430501-a666-4c24-b234-eeac5ccb70f6"

#define CALICALENDARVIEWCONTROLLER_IID \
  {0x40430501, 0xa666, 0x4c24, \
    { 0xb2, 0x34, 0xee, 0xac, 0x5c, 0xcb, 0x70, 0xf6 }}

class NS_NO_VTABLE calICalendarViewController : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALICALENDARVIEWCONTROLLER_IID)

  /**
   * Create an event, with an optional start time and optional end
   * time in the given Calendar.  The Calendar will be the
   * displayCalendar set on the View which invokes this method
   * on the controller, or null, if the views wish to delegate the
   * choice of the calendar to the controller.
   *
   * If neither aStartTime or aEndTime are given, the user wants to
   * create a generic event with no information prefilled.
   *
   * If aStartTime is given and is a date, the user wants to
   * create an all day event, optionally a multi-all-day event if
   * aEndTime is given (and is also a date).
   *
   * If aStartTime is given and is a time, but no aEndTime is
   * given, the user wants to create an event starting at
   * aStartTime and of the default duration.  The controller has the
   * option of creating this event automatically or via the dialog.
   *
   * If both aStartTime and aEndTime are given as times, then
   * the user wants to create an event going from aStartTime
   * to aEndTime.
   */
  /* void createNewEvent (in calICalendar aCalendar, in calIDateTime aStartTime, in calIDateTime aEndTime); */
  NS_IMETHOD CreateNewEvent(calICalendar *aCalendar, calIDateTime *aStartTime, calIDateTime *aEndTime) = 0;

  /**
   * Modify aOccurrence.  If aNewStartTime and aNewEndTime are given,
   * update the event to those times.  If aNewTitle is given, modify the title
   * of the item.  If no parameters are given, ask the user to modify.
   */
  /* void modifyOccurrence (in calIItemBase aOccurrence, in calIDateTime aNewStartTime, in calIDateTime aNewEndTime, in AString aNewTitle); */
  NS_IMETHOD ModifyOccurrence(calIItemBase *aOccurrence, calIDateTime *aNewStartTime, calIDateTime *aNewEndTime, const nsAString & aNewTitle) = 0;

  /**
   * Delete all events in the given array. If more than one event is passed,
   * this will prompt whether to delete just this occurrence or all occurrences.
   * All passed events will be handled in one transaction, i.e undoing this will
   * make all events reappear.
   *
   * @param aCount          The number of events in the array
   * @param aOccurrences    An array of Items/Occurrences to delete
   * @param aUseParentItems If set, each occurence will have its parent item
   *                        deleted.
   * @param aDoNotConfirm   If set, the events will be deleted without
   *                        confirmation.
   */
  /* void deleteOccurrences (in PRUint32 aCount, [array, size_is (aCount)] in calIItemBase aOccurrences, in boolean aUseParentItems, in boolean aDoNotConfirm); */
  NS_IMETHOD DeleteOccurrences(PRUint32 aCount, calIItemBase **aOccurrences, PRBool aUseParentItems, PRBool aDoNotConfirm) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALICALENDARVIEWCONTROLLER \
  NS_IMETHOD CreateNewEvent(calICalendar *aCalendar, calIDateTime *aStartTime, calIDateTime *aEndTime); \
  NS_IMETHOD ModifyOccurrence(calIItemBase *aOccurrence, calIDateTime *aNewStartTime, calIDateTime *aNewEndTime, const nsAString & aNewTitle); \
  NS_IMETHOD DeleteOccurrences(PRUint32 aCount, calIItemBase **aOccurrences, PRBool aUseParentItems, PRBool aDoNotConfirm); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALICALENDARVIEWCONTROLLER(_to) \
  NS_IMETHOD CreateNewEvent(calICalendar *aCalendar, calIDateTime *aStartTime, calIDateTime *aEndTime) { return _to CreateNewEvent(aCalendar, aStartTime, aEndTime); } \
  NS_IMETHOD ModifyOccurrence(calIItemBase *aOccurrence, calIDateTime *aNewStartTime, calIDateTime *aNewEndTime, const nsAString & aNewTitle) { return _to ModifyOccurrence(aOccurrence, aNewStartTime, aNewEndTime, aNewTitle); } \
  NS_IMETHOD DeleteOccurrences(PRUint32 aCount, calIItemBase **aOccurrences, PRBool aUseParentItems, PRBool aDoNotConfirm) { return _to DeleteOccurrences(aCount, aOccurrences, aUseParentItems, aDoNotConfirm); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALICALENDARVIEWCONTROLLER(_to) \
  NS_IMETHOD CreateNewEvent(calICalendar *aCalendar, calIDateTime *aStartTime, calIDateTime *aEndTime) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateNewEvent(aCalendar, aStartTime, aEndTime); } \
  NS_IMETHOD ModifyOccurrence(calIItemBase *aOccurrence, calIDateTime *aNewStartTime, calIDateTime *aNewEndTime, const nsAString & aNewTitle) { return !_to ? NS_ERROR_NULL_POINTER : _to->ModifyOccurrence(aOccurrence, aNewStartTime, aNewEndTime, aNewTitle); } \
  NS_IMETHOD DeleteOccurrences(PRUint32 aCount, calIItemBase **aOccurrences, PRBool aUseParentItems, PRBool aDoNotConfirm) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteOccurrences(aCount, aOccurrences, aUseParentItems, aDoNotConfirm); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calICalendarViewController
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALICALENDARVIEWCONTROLLER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calICalendarViewController)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void createNewEvent (in calICalendar aCalendar, in calIDateTime aStartTime, in calIDateTime aEndTime); */
NS_IMETHODIMP _MYCLASS_::CreateNewEvent(calICalendar *aCalendar, calIDateTime *aStartTime, calIDateTime *aEndTime)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void modifyOccurrence (in calIItemBase aOccurrence, in calIDateTime aNewStartTime, in calIDateTime aNewEndTime, in AString aNewTitle); */
NS_IMETHODIMP _MYCLASS_::ModifyOccurrence(calIItemBase *aOccurrence, calIDateTime *aNewStartTime, calIDateTime *aNewEndTime, const nsAString & aNewTitle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteOccurrences (in PRUint32 aCount, [array, size_is (aCount)] in calIItemBase aOccurrences, in boolean aUseParentItems, in boolean aDoNotConfirm); */
NS_IMETHODIMP _MYCLASS_::DeleteOccurrences(PRUint32 aCount, calIItemBase **aOccurrences, PRBool aUseParentItems, PRBool aDoNotConfirm)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calICalendarViewController_h__ */
